"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const socket_client_1 = require("../../utils/socket-client");
const commander_1 = require("commander");
const logging_1 = require("../../utils/logging");
const redis_1 = require("../../utils/redis");
const fs_1 = require("fs");
const yaml_1 = require("yaml");
const path_1 = require("path");
const shelljs_1 = tslib_1.__importDefault(require("shelljs"));
const logger = logging_1.getLogger();
logger.info("start subscribe...");
commander_1.program.parse(process.argv);
/**
 * 连接成功
 */
socket_client_1.socket.on("connect", () => {
    logger.info("connected socket service！");
});
/**
 * 获取代码，写出到文件
 */
socket_client_1.socket.on('eating', msg => {
    logger.info(`触发 eating 事件...`);
    redis_1.redisHandler(clt => {
        clt.get("outfile", (error, data) => {
            logger.info(`获取输出路径 ${data} ...`);
            if (error) {
                logger.error(error);
            }
            else if (data) {
                const content = yaml_1.parse(msg.data);
                const theDirective = path_1.dirname(data);
                if (!fs_1.existsSync(theDirective)) {
                    fs_1.mkdirSync(theDirective, { recursive: true });
                }
                fs_1.writeFile(data, yaml_1.stringify(content), err => {
                    if (err) {
                        logger.error(err.message);
                    }
                });
                logger.info(`write file ${data} success;`);
            }
            clt.quit();
        });
    });
});
socket_client_1.socket.on('command', msg => {
    try {
        shelljs_1.default.exec(msg);
        logger.info(`触发 command 事件 ${msg}...`);
    }
    catch (error) {
        logger.error(error.message);
    }
});
/**
 * 缓存配置代码到本地
 */
socket_client_1.socket.on('code', msg => {
    logger.info(`触发 cached 事件...`);
    redis_1.redisHandler(clt => {
        clt.get("out_cache_file", (error, data) => {
            logger.info(`获取缓存路径 ${data} ...`);
            if (error) {
                logger.error(error);
            }
            else if (data) {
                fs_1.writeFile(data, msg, err => {
                    if (err) {
                        logger.error(err.message);
                    }
                });
                logger.info(`write file ${data} success;`);
            }
            clt.quit();
        });
    });
});
// 关闭连接到时候调用
socket_client_1.socket.on("unconnect", () => {
    logger.info("unconnect...");
});
