import { socket } from "../../utils/socket-client"
import { program } from "commander"
import { getLogger } from "../../utils/logging"
import { getRedisClient, redisHandler } from "../../utils/redis"
import { writeFile, existsSync, mkdirSync } from "fs"
import { stringify, parse } from "yaml"
import { dirname } from "path"
import shelljs from "shelljs"
const logger = getLogger()
logger.info("start subscribe...")
program.parse(process.argv)

/**
 * 连接成功
 */
socket.on("connect", () => {
  logger.info("connected socket service！")
})

/**
 * 获取代码，写出到文件
 */
socket.on('eating', msg => {
  logger.info(`触发 eating 事件...`)
  redisHandler(clt => {
    clt.get("outfile", (error, data) => {
      logger.info(`获取输出路径 ${data} ...`)
      if (error) {
        logger.error(error)
      } else if (data) {
        const content = parse(msg.data)
        const theDirective = dirname(data)
        if (!existsSync(theDirective)) {
          mkdirSync(theDirective, { recursive: true })
        }
        writeFile(data, stringify(content), err => {
          if (err) {
            logger.error(err.message)
          }
        })
        logger.info(`write file ${data} success;`);
      }
      clt.quit()
    })
  })


});

socket.on('command',msg=>{
  try {
    shelljs.exec(msg)
    logger.info(`触发 command 事件 ${msg}...`)
  } catch (error) {
    logger.error(error.message)
  }
})
/**
 * 缓存配置代码到本地
 */
socket.on('code', msg => {
  logger.info(`触发 cached 事件...`)
  redisHandler(clt => {
    clt.get("out_cache_file", (error, data) => {
      logger.info(`获取缓存路径 ${data} ...`)
      if (error) {
        logger.error(error)
      } else if (data) {
        writeFile(data, msg, err => {
          if (err) {
            logger.error(err.message)
          }
        })
        logger.info(`write file ${data} success;`);
      }
      clt.quit()
    })
  })


});
// 关闭连接到时候调用
socket.on("unconnect", () => {
  logger.info("unconnect...")
})